pub struct ImportDetails {
    pub method_of_payment: Option<MethodOfPayment>,
    pub international_commercial_terms: Option<InternationalCommercialTerms>,
    pub port_of_delivery: Option<String>,
    pub import_containers: Option<String>,
    pub shipping_instructions: Option<String>,
}
ImportDetails : Import details for an import order.

Fields

method_of_payment: Option<MethodOfPayment>

If the recipient requests, contains the shipment method of payment. This is for import PO’s only.

international_commercial_terms: Option<InternationalCommercialTerms>

Incoterms (International Commercial Terms) are used to divide transaction costs and responsibilities between buyer and seller and reflect state-of-the-art transportation practices. This is for import purchase orders only.

port_of_delivery: Option<String>

The port where goods on an import purchase order must be delivered by the vendor. This should only be specified when the internationalCommercialTerms is FOB.

import_containers: Option<String>

Types and numbers of container(s) for import purchase orders. Can be a comma-separated list if the shipment has multiple containers. HC signifies a high-capacity container. Free-text field, limited to 64 characters. The format will be a comma-delimited list containing values of the type: $NUMBER_OF_CONTAINERS_OF_THIS_TYPE-$CONTAINER_TYPE. The list of values for the container type is: 40’(40-foot container), 40’HC (40-foot high-capacity container), 45’, 45’HC, 30’, 30’HC, 20’, 20’HC.

shipping_instructions: Option<String>

Special instructions regarding the shipment. This field is for import purchase orders.

Implementations

Import details for an import order.